@@ -3,7 +3,7 @@ package SQL::Format;
 use strict;
 use warnings;
 use 5.008_001;
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 use Exporter 'import';
 use Carp qw(croak carp);
@@ -183,14 +183,15 @@ sub _table {
 }
 
 sub _where {
-    my ($self, $val, $bind) = @_;
+    my ($self, $val, $bind, $logic) = @_;
 
     if (ref $val eq 'ARRAY') {
         my @ret;
         for my $v (@$val) {
             push @ret, $self->_where($v, $bind);
         }
-        return @ret == 1 ? $ret[0] : join ' OR ', map { "($_)" } @ret;
+        $logic ||= 'OR';
+        return @ret == 1 ? $ret[0] : join " $logic ", map { "($_)" } @ret;
     }
 
     return unless ref $val eq 'HASH';
@@ -201,6 +202,9 @@ sub _where {
         if (uc $org_key eq '-OR') {
             $k = $self->_where($v, $bind);
         }
+        elsif (uc $org_key eq '-AND') {
+            $k = $self->_where($v, $bind, 'AND');
+        }
         elsif (ref $v eq 'ARRAY') {
             if (
                    ref $v->[0]
